( cd usr/man/man1 ; rm -rf vdeqemu.1.gz )
( cd usr/man/man1 ; ln -sf vdeq.1.gz vdeqemu.1.gz )
( cd usr/man/man1 ; rm -rf vdecmd.1.gz )
( cd usr/man/man1 ; ln -sf unixcmd.1.gz vdecmd.1.gz )
( cd usr/man/man1 ; rm -rf vdekvm.1.gz )
( cd usr/man/man1 ; ln -sf vdeq.1.gz vdekvm.1.gz )
( cd usr/bin ; rm -rf vdecmd )
( cd usr/bin ; ln -sf unixcmd vdecmd )
( cd usr/bin ; rm -rf vdekvm )
( cd usr/bin ; ln -sf vdeq vdekvm )
( cd usr/bin ; rm -rf vdeqemu )
( cd usr/bin ; ln -sf vdeq vdeqemu )
( cd usr/lib64 ; rm -rf libvdemgmt.so.0 )
( cd usr/lib64 ; ln -sf libvdemgmt.so.0.0.1 libvdemgmt.so.0 )
( cd usr/lib64 ; rm -rf libvdeplug.so.3 )
( cd usr/lib64 ; ln -sf libvdeplug.so.3.0.1 libvdeplug.so.3 )
( cd usr/lib64 ; rm -rf libvdehist.so )
( cd usr/lib64 ; ln -sf libvdehist.so.0.0.1 libvdehist.so )
( cd usr/lib64 ; rm -rf libvdemgmt.so )
( cd usr/lib64 ; ln -sf libvdemgmt.so.0.0.1 libvdemgmt.so )
( cd usr/lib64 ; rm -rf libvdesnmp.so )
( cd usr/lib64 ; ln -sf libvdesnmp.so.0.0.1 libvdesnmp.so )
( cd usr/lib64 ; rm -rf libvdesnmp.so.0 )
( cd usr/lib64 ; ln -sf libvdesnmp.so.0.0.1 libvdesnmp.so.0 )
( cd usr/lib64 ; rm -rf libvdehist.so.0 )
( cd usr/lib64 ; ln -sf libvdehist.so.0.0.1 libvdehist.so.0 )
( cd usr/lib64 ; rm -rf libvdeplug.so )
( cd usr/lib64 ; ln -sf libvdeplug.so.3.0.1 libvdeplug.so )
